@@ -1,10 +1,7 @@
 import webbrowser
-import os
 import turtle
-import random
 import time
-from matplotlib import ticker
-import pkgF12
+
 
 def tickerMsg():
     # sets background
@@ -101,7 +98,7 @@ def tickerMsg():
     turtle.color("black")
 
 
-def f1func(number):
+def year(number):
     # creating nd viewing the html files in python
 
     # to open/create a new html file in the write mode
@@ -133,15 +130,15 @@ def f1func(number):
     # f.close()
 
     # 1st method how to open html files in chrome usingimport time.
-    start = time. time()
-    tickerMsg()
-    stop = time. time()
 
-    print("The time of the run:", stop - start)
-    filename = 'template\\GFG.html'
-    webbrowser.open_new_tab(filename)
-    path = os.path.dirname(pkgF12.__file__)
-    print("path", path,"This Is a F1Func updated", filename)
+    tickerMsg()
+    time.sleep(3)
+    webbrowser.open_new_tab('https://mdamirpathan.github.io/')
+    try :
+        print("Site Ko reload Kar In case scrolling Stop Nahi huaa \n Mota bhai Ko Dikah Ab 😆😆😆")
+    except:
+        print("Site Ko reload Kar In case scrolling Stop Nahi huaa \n Mota bhai Ko Dikah Ab :):)")
+    
     return number
 
 
